import { ClientCookieManager } from "./clientCookieManager";
import { ClientCache } from "./clientCache";
import type { Language } from "../constants/lang";
import type { RecordCard, AbyssBattle, GenshinUserData, RealTimeNote, CharacterData, Diary } from "../interface";
export declare class Client {
    private options;
    private cookieManager;
    cache: ClientCache | null;
    /**
     * @param {Object} options - The options to use.
     */
    constructor(options: {
        language: Language | Language.EnglishUS;
        cookieManager?: ClientCookieManager;
        cache?: boolean;
    });
    setltoken(ltoken: string): void;
    setltuid(ltuid: string): void;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getAbyssBattle(uid: string, previous?: boolean): Promise<AbyssBattle>;
    /**
     * @param {string} uid - HoYolab uid.
     */
    getGameRecordCard(uid: string): Promise<RecordCard>;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getGenshinUser(uid: string): Promise<GenshinUserData>;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getRealTimeNotes(uid: string): Promise<RealTimeNote>;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getCharacter(uid: string): Promise<CharacterData>;
    /**
     *  @param {string} uid - Genshin Impact game uid.
     */
    getTravelDiary(uid: string): Promise<Diary>;
}
