"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const index_1 = require("../index");
const clientCookieManager_1 = require("./clientCookieManager");
const clientCache_1 = require("./clientCache");
class Client {
    /**
     * @param {Object} options - The options to use.
     */
    constructor(options) {
        var _a;
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.options = options;
        this.cookieManager = options.cookieManager || new clientCookieManager_1.ClientCookieManager();
        this.options.cache = (_a = options.cache) !== null && _a !== void 0 ? _a : true;
        this.cache = this.options.cache ? new clientCache_1.ClientCache() : null;
    }
    setltoken(ltoken) {
        this.cookieManager.setltoken(ltoken);
    }
    setltuid(ltuid) {
        this.cookieManager.setltuid(ltuid);
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getAbyssBattle(uid, previous) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.SpiralAbyss(this.cache).fetch(uid, language, cookie, previous);
        return res;
    }
    /**
     * @param {string} uid - HoYolab uid.
     */
    async getGameRecordCard(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.GameRecordCard(this.cache).fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getGenshinUser(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.GenshinUser(this.cache).fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getRealTimeNotes(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.RealTimeNotes(this.cache).fetch(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getCharacter(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.Charcters(this.cache).fetch(uid, language, cookie);
        return res;
    }
    /**
     *  @param {string} uid - Genshin Impact game uid.
     */
    async getTravelDiary(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.TravelerDiary(this.cache).fetch(uid, language, cookie);
        return res;
    }
}
exports.Client = Client;
