"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientCookieManager = void 0;
class ClientCookieManager {
    constructor() {
        Object.defineProperty(this, "cookie", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: {
                ltoken: [],
                ltuid: [],
            }
        });
    }
    /**
     * @returns {number} - The amount of cookies.
     */
    amount() {
        return this.cookie.ltoken.length;
    }
    setltoken(ltoken) {
        this.cookie.ltoken.push(ltoken);
    }
    setltuid(ltuid) {
        this.cookie.ltuid.push(ltuid);
    }
    /**
     * @description Get the ltoken and ltuid for request.
     * @returns {Object} - The ltoken and ltuid.
     */
    get() {
        if (this.amount() === 1) {
            return {
                ltoken: this.cookie.ltoken[0],
                ltuid: this.cookie.ltuid[0],
                key: 0,
                cookie: `ltoken=${this.cookie.ltoken[0]};ltuid=${this.cookie.ltuid[0]};`,
            };
        }
        const randomIndex = Math.floor(Math.random() * this.amount());
        return {
            ltoken: this.cookie.ltoken[randomIndex],
            ltuid: this.cookie.ltuid[randomIndex],
            cookie: `ltoken=${this.cookie.ltoken[randomIndex]}; ltuid=${this.cookie.ltuid[randomIndex]}`,
            key: randomIndex,
        };
    }
    /**
     * @param key - The key to remove.
     */
    delete(key) {
        this.cookie.ltoken.splice(key, 1);
        this.cookie.ltuid.splice(key, 1);
    }
    clear() {
        this.cookie.ltoken = [];
        this.cookie.ltuid = [];
    }
    getAll() {
        const cookie = {};
        for (let i = 0; i < this.amount(); i++) {
            cookie[i] = {
                ltoken: this.cookie.ltoken[i],
                ltuid: this.cookie.ltuid[i],
            };
        }
        return cookie;
    }
}
exports.ClientCookieManager = ClientCookieManager;
