"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Activities = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const error_1 = require("../utils/error");
const base_1 = require("./base");
class Activities extends base_1.BaseRoute {
    constructor(clientCache) {
        super(clientCache);
    }
    /**
     * @param {string} uid The uid to set
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    async fetch(uid, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.get("activities", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            Cookie: cookie,
        }, {
            server: (0, getServer_1.checkServerRegion)(uid),
            role_id: uid,
        });
        if (res.retcode === 0) {
            const { data } = res;
            const returnData = {
                sumo: data.activities[0].sumo.records,
                rogue: data.activities[1].rogue.records,
                channeller_slab_copy: data.activities[2].channeller_slab_copy,
                potion: data.activities[3].potion.records,
                sumo_second: data.activities[4].sumo_second.records,
                crystal: data.activities[5].crystal.records,
                perilous: data.activities[6].perilous.records,
                summer_v2: data.activities[7].summer_v2,
                spray: data.activities[8].spray,
            };
            if (this.clientCache) {
                this.clientCache.set(`${uid}-activities`, returnData);
            }
            return returnData;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.Activities = Activities;
