"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Charcters = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const error_1 = require("../utils/error");
const base_1 = require("./base");
class Charcters extends base_1.BaseRoute {
    constructor(clientCache) {
        super(clientCache);
    }
    /**
     * @param {string} uid The uid to set
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    async fetch(uid, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.post("character", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            Cookie: cookie,
        }, {
            role_id: uid,
            server: (0, getServer_1.checkServerRegion)(uid),
        });
        if (res.retcode === 0) {
            const { data } = res;
            if (this.clientCache) {
                this.clientCache.set(`${uid}-genshinCharacters`, data);
            }
            return data.avatars;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
    /**
     * @param {number} characterId The avatar's id
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    async getAvatarInfo(characterId, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.post("avatarBasicInfo", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            Cookie: cookie,
        }, {
            character_ids: [characterId],
        });
        if (res.retcode === 0) {
            const { data } = res;
            return data.avatars[0];
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.Charcters = Charcters;
