"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.request = exports.urlOption = void 0;
const tslib_1 = require("tslib");
const constants_1 = require("../constants/constants");
const undici_1 = require("undici");
const generate_ds_1 = tslib_1.__importDefault(require("./generate_ds"));
var urlOption;
(function (urlOption) {
    urlOption["hoyolab"] = "hoyolab";
    urlOption["dailyrewards"] = "dailyrewards";
    urlOption["diary"] = "diary";
})(urlOption = exports.urlOption || (exports.urlOption = {}));
/**
 * @description Creates a new instance for the request
 */
class HTTPRequest {
    constructor(option) {
        Object.defineProperty(this, "baseURL", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "withUA", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "withDS", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "language", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.baseURL = constants_1.Genshin_Battle_API_URL;
        if ((option === null || option === void 0 ? void 0 : option.type) === urlOption.hoyolab) {
            this.baseURL = constants_1.Genshin_Hoyolab_API_URL;
        }
        if ((option === null || option === void 0 ? void 0 : option.type) === urlOption.dailyrewards) {
            this.baseURL = constants_1.Genshin_Hoyolab_REWARD_URL;
        }
        if ((option === null || option === void 0 ? void 0 : option.type) === urlOption.diary) {
            this.baseURL = constants_1.Genshin_Hoyolab_DIARY_URL;
        }
        this.withUA = (option === null || option === void 0 ? void 0 : option.withUA) || false;
        this.withDS = (option === null || option === void 0 ? void 0 : option.withDS) || false;
        this.language = "en-us";
    }
    async get(url, headers, params) {
        const { body: res, statusCode } = await (0, undici_1.request)(`${this.baseURL}${url}`, {
            method: "GET",
            headers: {
                "User-Agent": this.withUA ? constants_1.UA : undefined,
                DS: this.withDS ? (0, generate_ds_1.default)() : undefined,
                "x-rpc-language": this.language,
                ...headers,
            },
            query: params,
        });
        if (statusCode !== 200) {
            throw new Error(`Request failed with status code ${statusCode}`);
        }
        const resData = await res.json();
        if (resData.retcode === -100) {
            return {
                message: "Invalid cookie",
                retcode: -100,
            };
        }
        if (resData.retcode === 10001) {
            return {
                message: "Invalid cookie",
                retcode: 10001,
            };
        }
        if (resData.retcode === 10101) {
            return {
                message: "Cannot get data for more than 30 accounts per cookie per day",
                retcode: 10101,
            };
        }
        return resData;
    }
    async post(url, headers, data, params) {
        const { body: res, statusCode } = await (0, undici_1.request)(`${this.baseURL}${url}`, {
            method: "POST",
            headers: {
                "User-Agent": this.withUA ? constants_1.UA : undefined,
                DS: this.withDS ? (0, generate_ds_1.default)() : undefined,
                "x-rpc-language": this.language,
                ...headers,
            },
            body: JSON.stringify(data),
            query: params,
        });
        if (statusCode !== 200) {
            throw new Error(`Request failed with status code ${statusCode}`);
        }
        const resData = await res.json();
        return resData;
    }
    setLanguage(language) {
        this.language = language;
    }
}
exports.request = HTTPRequest;
